@@ -176,7 +176,12 @@ def knscore(jd, fid, magpsf, sigmapsf, model_path=None, pcs_path=None, npcs=None
 
     matrix_clean = matrix[~zeros]
 
-    # Make predictions
+    # If all alerts are flagged as bad
+    if np.shape(matrix_clean) == (0, len(KN_FEATURE_NAMES_1PC)):
+        to_return = np.zeros(len(jd), dtype=float)
+        return pd.Series(to_return)
+
+    # Otherwise make predictions
     probabilities = model.predict_proba(matrix_clean.values)
     probabilities_notkne = np.zeros(len(test_features))
     probabilities_kne = np.zeros(len(test_features))
