@@ -1,4 +1,4 @@
-# Copyright 2020 AstroLab Software
+# Copyright 2020-2021 AstroLab Software
 # Author: Julien Peloton
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,6 +14,7 @@
 # limitations under the License.
 from pyspark.sql import functions as F
 
+import pandas as pd
 import numpy as np
 import pickle
 
@@ -106,6 +107,27 @@ def load_scikit_model(fn: str = ''):
     """
     return pickle.load(open(fn, 'rb'))
 
+def load_pcs(fn, npcs):
+    """ Load PC from disk into a Pandas DataFrame
+
+    Parameters
+    ----------
+    fn: str
+        Filename. This file should be known from all machines!
+    npcs: int
+        Number of principal components to load
+
+    Return
+    ----------
+    clf: sklearn.ensemble.forest.RandomForestClassifier
+    """
+    comp = pd.read_csv(fn)
+    pcs = {}
+    for i in range(npcs):
+        pcs[i + 1] = comp.iloc[i].values
+
+    return pd.DataFrame(pcs)
+
 
 if __name__ == "__main__":
     """ Execute the test suite """
